const system = require("../../../system");
const ServiceBase = require("../../sve.base");

class PushFailureLogService extends ServiceBase {
  constructor() {
    super("opLogs", ServiceBase.getDaoName(PushFailureLogService));
  }
  async getPushErrorList(actionBody, req) {
    var pageIndex = actionBody.pageIndex || 1;
    var pageSize = actionBody.pageSize || 20;
    if (pageSize > 100) {
      pageSize = 100;
    }
    var offset = (pageIndex - 1) * pageSize;
    var sqlCount = "select count(1) as dataCount from op_error_log";
    var sql = "select	id,`queued_name`,`identify_code`,`op_title`,`push_content`, `result_info`,`request_id`,`created_at` from op_error_log";
    var params = null;
    if (actionBody.messageBody) {
      sql = sql + " WHERE push_content like :push_content";
      params = { push_content: "%" + actionBody.messageBody + "%" };
    }
    if (actionBody.identifyCode) {
      sql = sql + (params ? " and identify_code like :identify_code" : " WHERE identify_code like :identify_code");
      if (params) {
        params.identify_code = "%" + actionBody.identifyCode + "%";
      } else {
        params = { identify_code: "%" + actionBody.identifyCode + "%" };
      }
    }
    if (actionBody.requestIdInfo) {
      sql = sql + (params ? " and request_id =:request_id" : " WHERE request_id =:request_id");
      if (params) {
        params.request_id = actionBody.requestIdInfo;
      } else {
        params = { request_id: actionBody.requestIdInfo };
      }
    }
    sql = sql + " order by id desc LIMIT " + offset + ", " + pageSize + "; ";

    var tmpCountList = await this.customQuery(sqlCount, null);
    var tmpList = await this.customQuery(sql, params);
    var tmpCount = 0;
    if (tmpCountList && tmpCountList.length > 0) {
      tmpCount = tmpCountList[0].dataCount;
    }
    var reslut = system.getResultSuccess(tmpList);
    reslut.totalCount = tmpCount;
    return reslut;
  }
  async getPushFailureList(actionBody, req) {
    var pageIndex = actionBody.pageIndex || 1;
    var pageSize = actionBody.pageSize || 20;
    if (pageSize > 100) {
      pageSize = 100;
    }
    var offset = (pageIndex - 1) * pageSize;
    var sqlCount = "select count(1) as dataCount from x_push_failure_log";
    var sql = "select	id,`queued_name`,`identify_code`,`op_title`,`push_content`, `result_info`,`request_id`,`created_at` from x_push_failure_log";
    var params = null;
    if (actionBody.messageBody) {
      sql = sql + " WHERE push_content like :push_content";
      params = { push_content: "%" + actionBody.messageBody + "%" };
    }
    if (actionBody.identifyCode) {
      sql = sql + (params ? " and identify_code like :identify_code" : " WHERE identify_code like :identify_code");
      if (params) {
        params.identify_code = "%" + actionBody.identifyCode + "%";
      } else {
        params = { identify_code: "%" + actionBody.identifyCode + "%" };
      }
    }
    if (actionBody.requestIdInfo) {
      sql = sql + (params ? " and request_id =:request_id" : " WHERE request_id =:request_id");
      if (params) {
        params.request_id = actionBody.requestIdInfo;
      } else {
        params = { request_id: actionBody.requestIdInfo };
      }
    }
    sql = sql + " order by id desc LIMIT " + offset + ", " + pageSize + "; ";

    var tmpCountList = await this.customQuery(sqlCount, null);
    var tmpList = await this.customQuery(sql, params);
    var tmpCount = 0;
    if (tmpCountList && tmpCountList.length > 0) {
      tmpCount = tmpCountList[0].dataCount;
    }
    var reslut = system.getResultSuccess(tmpList);
    reslut.totalCount = tmpCount;
    return reslut;
  }
  async getPushAgainFailureLog(actionBody, req) {
    if (!actionBody.id) {
      return system.getResult(null, "id can not be empty");
    }
    var sql = "select	id,`queued_name`,`identify_code`,`op_title`,`push_content`, `result_info`,`request_id`,`created_at` from x_push_failure_log where id=:id limit 1";
    var params = { id: actionBody.id };
    var tmpList = await this.customQuery(sql, params);
    var item = null;
    if (tmpList && tmpList.length > 0) {
      item = tmpList[0];
    }
    if (!item) {
      return system.getResult(null, "data is empty");
    }
    if (!item.push_content.pushUrl) {
      return system.getResult(null, "push_content pushUrl is empty");
    }
    var resultParam = {
      actionBody: {
        pushUrl: item.push_content.pushUrl,// Y 推送地址
        actionType: item.push_content.actionType,// Y 推送地址接收时的功能名称
        notifyUrl: item.push_content.notifyUrl,// N 推送成功后通知的Url                 
        identifyCode: item.push_content.identifyCode,// Y 操作的业务标识
        messageBody: item.push_content.messageBody,
        headData: null //N 请求头信息，Json格式，如：{token:"XXXXXXX"}
      }
    }
    return system.getResultSuccess(resultParam);
  }
  async delFailureLog(actionBody, req) {
    if (!actionBody.id) {
      return system.getResult(null, "id can not be empty");
    }
    var sql = "DELETE from x_push_failure_log where id=:id";
    var params = { id: actionBody.id };
    await this.customDelete(sql, params);
    return system.getResultSuccess();
  }
}
module.exports = PushFailureLogService;
